==> ejc-zdsmaterialb-api-3.0.0-20240802.102206-4-sources.jar: com/ejianc/business/zdsmaterial/plan/control/vo/ControlPlanImportVO.java <==
package com.ejianc.business.zdsmaterial.plan.control.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 物资总控计划导入
 * 
 * @author generator
 * 
 */
public class ControlPlanImportVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialTypeCode; // 物资分类编码
    private String property; // 属性
    private String propertyValue; // 属性值
    private Long unitId; // 计量单位Id
    private String unitName; // 计量单位名称
    private BigDecimal num; // 总控量
    private String memo; // 备注
    private Integer sourceType; // 来源：1-档案，2-新增
    private Integer rowType; // 行类型：1-新增，2-变更
    private String reason; // 超量原因
    private BigDecimal beforeNum; // 变更前总控量
    private BigDecimal afterNum; // 变更后总控量
    private BigDecimal purchaseNum; // 累计采购量
    private Long parentMaterialTypeId; // 二级分类主键
    private Integer hasNewPropertyVal; // 是否新增属性值：0-否，1-是
    private String productCode; // 产品代码
    private Long brandId; // 品牌主键
    private String brandName; // 品牌名称
    private String description; // 描述
    private String parentMaterialTypeCode; // 二级分类编码
    private String parentMaterialTypeName; // 二级分类名称


    public String getParentMaterialTypeCode() {
        return parentMaterialTypeCode;
    }

    public void setParentMaterialTypeCode(String parentMaterialTypeCode) {
        this.parentMaterialTypeCode = parentMaterialTypeCode;
    }

    public String getParentMaterialTypeName() {
        return parentMaterialTypeName;
    }

    public void setParentMaterialTypeName(String parentMaterialTypeName) {
        this.parentMaterialTypeName = parentMaterialTypeName;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    public String getProperty() {
        return property;
    }

    public void setProperty(String property) {
        this.property = property;
    }
    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public Integer getRowType() {
        return rowType;
    }

    public void setRowType(Integer rowType) {
        this.rowType = rowType;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    public BigDecimal getBeforeNum() {
        return beforeNum;
    }

    public void setBeforeNum(BigDecimal beforeNum) {
        this.beforeNum = beforeNum;
    }
    public BigDecimal getAfterNum() {
        return afterNum;
    }

    public void setAfterNum(BigDecimal afterNum) {
        this.afterNum = afterNum;
    }
    public BigDecimal getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(BigDecimal purchaseNum) {
        this.purchaseNum = purchaseNum;
    }
    public Long getParentMaterialTypeId() {
        return parentMaterialTypeId;
    }

    public void setParentMaterialTypeId(Long parentMaterialTypeId) {
        this.parentMaterialTypeId = parentMaterialTypeId;
    }
    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }
    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    @ReferSerialTransfer(referCode="ref-zdsBrand")
    public Long getBrandId() {
        return brandId;
    }

    @ReferDeserialTransfer
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    
}

==> ejc-zdsmaterialb-api-3.0.0-20251113.072200-93-sources.jar: com/ejianc/business/zdsmaterial/plan/control/vo/ControlPlanImportVO.java <==
package com.ejianc.business.zdsmaterial.plan.control.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 物资总控计划导入
 * 
 * @author generator
 * 
 */
public class ControlPlanImportVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialTypeCode; // 物资分类编码
    private String property; // 属性
    private String propertyValue; // 属性值
    private Long unitId; // 计量单位Id
    private String unitName; // 计量单位名称
    private BigDecimal num; // 总控量
    private String memo; // 备注
    private Integer sourceType; // 来源：1-档案，2-新增
    private Integer rowType; // 行类型：1-新增，2-变更
    private String reason; // 超量原因
    private BigDecimal beforeNum; // 变更前总控量
    private BigDecimal afterNum; // 变更后总控量
    private BigDecimal purchaseNum; // 累计采购量
    private Long parentMaterialTypeId; // 二级分类主键
    private Integer hasNewPropertyVal; // 是否新增属性值：0-否，1-是
    private String productCode; // 产品代码
    private Long brandId; // 品牌主键
    private String brandName; // 品牌名称
    private String description; // 描述
    private String parentMaterialTypeCode; // 二级分类编码
    private String parentMaterialTypeName; // 二级分类名称


    public String getParentMaterialTypeCode() {
        return parentMaterialTypeCode;
    }

    public void setParentMaterialTypeCode(String parentMaterialTypeCode) {
        this.parentMaterialTypeCode = parentMaterialTypeCode;
    }

    public String getParentMaterialTypeName() {
        return parentMaterialTypeName;
    }

    public void setParentMaterialTypeName(String parentMaterialTypeName) {
        this.parentMaterialTypeName = parentMaterialTypeName;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    public String getProperty() {
        return property;
    }

    public void setProperty(String property) {
        this.property = property;
    }
    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public Integer getRowType() {
        return rowType;
    }

    public void setRowType(Integer rowType) {
        this.rowType = rowType;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    public BigDecimal getBeforeNum() {
        return beforeNum;
    }

    public void setBeforeNum(BigDecimal beforeNum) {
        this.beforeNum = beforeNum;
    }
    public BigDecimal getAfterNum() {
        return afterNum;
    }

    public void setAfterNum(BigDecimal afterNum) {
        this.afterNum = afterNum;
    }
    public BigDecimal getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(BigDecimal purchaseNum) {
        this.purchaseNum = purchaseNum;
    }
    public Long getParentMaterialTypeId() {
        return parentMaterialTypeId;
    }

    public void setParentMaterialTypeId(Long parentMaterialTypeId) {
        this.parentMaterialTypeId = parentMaterialTypeId;
    }
    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }
    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    @ReferSerialTransfer(referCode="ref-zdsBrand")
    public Long getBrandId() {
        return brandId;
    }

    @ReferDeserialTransfer
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    
}
